==> broadleaf-open-admin-platform-1.5.4-20120324.000219-12-sources.jar: org/broadleafcommerce/openadmin/client/dto/SandBoxInfo.java <==
/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.openadmin.client.dto;

import java.io.Serializable;

public class SandBoxInfo implements Serializable {

	private static final long serialVersionUID = 1L;
	
	protected Long sandBox;
	protected boolean commitImmediately = true;
    protected Long siteId;
    protected String name;

    public Long getSandBox() {
        return sandBox;
    }

    public void setSandBox(Long sandBox) {
        this.sandBox = sandBox;
    }

    public boolean isCommitImmediately() {
		return commitImmediately;
	}
	
	public void setCommitImmediately(boolean commitImmediately) {
		this.commitImmediately = commitImmediately;
	}

    public Long getSiteId() {
        return siteId;
    }

    public void setSiteId(Long siteId) {
        this.siteId = siteId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}

==> broadleaf-open-admin-platform-1.6.2-20120831.000303-9-sources.jar: org/broadleafcommerce/openadmin/client/dto/SandBoxInfo.java <==
/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.openadmin.client.dto;

import java.io.Serializable;

import com.google.gwt.user.client.rpc.IsSerializable;

public class SandBoxInfo implements IsSerializable, Serializable {

	private static final long serialVersionUID = 1L;
	
	protected Long sandBox;
	protected boolean commitImmediately = true;
    protected Long siteId;
    protected String name;

    public Long getSandBox() {
        return sandBox;
    }

    public void setSandBox(Long sandBox) {
        this.sandBox = sandBox;
    }

    public boolean isCommitImmediately() {
		return commitImmediately;
	}
	
	public void setCommitImmediately(boolean commitImmediately) {
		this.commitImmediately = commitImmediately;
	}

    public Long getSiteId() {
        return siteId;
    }

    public void setSiteId(Long siteId) {
        this.siteId = siteId;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}
